==> hasktags-0.71.2-38-x86_64.pkg.tar.xz: usr/share/haskell/register/hasktags.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hasktags
version: 0.71.2
id: hasktags-0.71.2-pds6DZIO9HDKZTjXsws3a
key: hasktags-0.71.2-pds6DZIO9HDKZTjXsws3a
license: BSD-3-Clause
copyright: The University Court of the University of Glasgow
maintainer: Jack Henahan <jhenahan@me.com>,
            Marc Weber <marco-oweber@gmx.de>,
            Marco Túlio Pimenta Gontijo <marcotmarcot@gmail.com>
author: The GHC Team
homepage: http://github.com/MarcWeber/hasktags
synopsis: Produces ctags "tags" and etags "TAGS" files for Haskell programs
description:
    Produces ctags "tags" and etags "TAGS" files for Haskell programs.
category: Development
abi: efb0c7855dabf596eab07fe14552e725
exposed: True
exposed-modules:
    Hasktags
hidden-modules: Tags DebugShow
import-dirs: /usr/lib/ghc-8.6.5/site-local/hasktags-0.71.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/hasktags-0.71.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hasktags-0.71.2
hs-libraries: HShasktags-0.71.2-pds6DZIO9HDKZTjXsws3a
depends:
    base-4.12.0.0 bytestring-0.10.8.2 directory-1.3.3.0
    filepath-1.4.2.1 json-0.9.3-KMo6fueTh6fHhtSWtpDb75
    microlens-platform-0.4.0-7mxRapTV0N3CaluHlAGhyj
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
haddock-interfaces: /usr/share/doc/hasktags/html/hasktags.haddock
haddock-html: /usr/share/doc/hasktags/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> hasktags-0.71.2-40-x86_64.pkg.tar.xz: usr/share/haskell/register/hasktags.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hasktags
version: 0.71.2
id: hasktags-0.71.2-DLWa1oW6F7gDei7w2aMWaf
key: hasktags-0.71.2-DLWa1oW6F7gDei7w2aMWaf
license: BSD-3-Clause
copyright: The University Court of the University of Glasgow
maintainer: Jack Henahan <jhenahan@me.com>,
            Marc Weber <marco-oweber@gmx.de>,
            Marco Túlio Pimenta Gontijo <marcotmarcot@gmail.com>
author: The GHC Team
homepage: http://github.com/MarcWeber/hasktags
synopsis: Produces ctags "tags" and etags "TAGS" files for Haskell programs
description:
    Produces ctags "tags" and etags "TAGS" files for Haskell programs.
category: Development
abi: 57261084ed2163152108c27bec564afe
exposed: True
exposed-modules:
    Hasktags
hidden-modules: Tags DebugShow
import-dirs: /usr/lib/ghc-8.6.5/site-local/hasktags-0.71.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/hasktags-0.71.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hasktags-0.71.2
hs-libraries: HShasktags-0.71.2-DLWa1oW6F7gDei7w2aMWaf
depends:
    base-4.12.0.0 bytestring-0.10.8.2 directory-1.3.3.0
    filepath-1.4.2.1 json-0.9.3-KMo6fueTh6fHhtSWtpDb75
    microlens-platform-0.4.0-C9zCSnZk6e82qjw2VQa4IH
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
haddock-interfaces: /usr/share/doc/hasktags/html/hasktags.haddock
haddock-html: /usr/share/doc/hasktags/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
